@@ -7,7 +7,7 @@ use strict;
 
 package POSIX::1003::FS;
 use vars '$VERSION';
-$VERSION = '0.99_05';
+$VERSION = '0.99_06';
 
 use base 'POSIX::1003::Module';
 
@@ -17,7 +17,7 @@ my @access = qw/access/;
 my @stat   = qw/stat lstat mkfifo mknod mkdir lchown
   S_ISDIR S_ISCHR S_ISBLK S_ISREG S_ISFIFO S_ISLNK S_ISSOCK S_ISWHT
 /;
-my @glob;  # qw/glob fnmatch/;
+my @glob = qw/posix_glob/;  # fnmatch
 
 sub S_ISDIR($)  { ($_[0] & S_IFMT()) == S_IFDIR()}
 sub S_ISCHR($)  { ($_[0] & S_IFMT()) == S_IFCHR()}
@@ -82,6 +82,37 @@ sub lchown($$@)
 }
 
 
+sub posix_glob($%)
+{   my ($patterns, %args) = @_;
+    my $flags  = $args{flags}
+       // $glob{GLOB_NOSORT}|$glob{GLOB_NOESCAPE}|$glob{GLOB_BRACE};
+    my $errfun = $args{on_error} || sub {0};
+
+    my ($err, @fns);
+    if(ref $patterns eq 'ARRAY')
+    {   foreach my $pattern (@$patterns)
+        {   my $thiserr = _glob(@fns, $pattern, $flags, $errfun);
+            next if !$thiserr || $thiserr==$glob{GLOB_NOMATCH};
+
+            $err = $thiserr;
+            last;
+        }
+    }
+    else
+    {   $err = _glob(@fns, $patterns, $flags, $errfun);
+    }
+
+    if($args{unique} && @fns)
+    {   my %seen;
+        @fns = grep !$seen{$_}++, @fns;
+    }
+
+    $err //= @fns ? $glob{GLOB_NOMATCH} : 0;
+    ($err, \@fns);
+}
+
+#---------
+
 sub _create_constant($)
 {   my ($class, $name) = @_;
     my $val = $fsys->{$name};
