@@ -63,12 +63,14 @@
 #endif
 
 #undef CACHE_UID
+#undef HAS_LOCKF
 #undef HAS_ULIMIT
 #undef HAS_GLOB
 #undef HAS_SETGROUPS
 #undef HAS_GETGROUPS
 #undef HAS_FCNTL
 #undef HAS_STRSIGNAL
+#undef HAS_CONFSTR
 
 /* mingw has empty stub 
  * Interesting: https://nanohub.org/infrastructure/rappture/svn/tags/1.0/gui/src/RpWinResource.c
